@@ -671,3 +671,89 @@ def bq_insert_overwrite_without_suffixes(sql, destination, partition=None, clust
         bq_insert_overwrite_table(sql, destination)
     else:
         bq_ctas(sql, destination, partition_by=partition, clustering_fields=clustering_fields)
+
+
+def get_storage_client(credentials=None, project_id=PROJECT_ID):
+    from google.cloud import storage
+
+    if credentials is None:
+        credentials = get_credentials()
+
+    return storage.Client(credentials=credentials, project=project_id)
+
+
+def storage_create_json(filename, storage_client=None, bucket_name=None, json_object=""):
+    import json
+
+    if storage_client is None:
+        raise Exception("storage_client is None")
+
+    if bucket_name is None or _storage_bucket_exist(storage_client, bucket_name) is False:
+        raise Exception("storage bucket is Not exist")
+
+    bucket = storage_client.get_bucket(bucket_name)
+    blob = bucket.blob(filename)
+
+    return blob.upload_from_string(data=json.dumps(json_object), content_type="application/json")
+
+
+def storage_create_text(filename, storage_client=None, bucket_name=None, text=""):
+    if storage_client is None:
+        raise Exception("storage_client is None")
+
+    if bucket_name is None or _storage_bucket_exist(storage_client, bucket_name) is False:
+        raise Exception("storage bucket is Not exist")
+
+    bucket = storage_client.get_bucket(bucket_name)
+    blob = bucket.blob(filename)
+    return blob.upload_from_string(data=text, content_type="application/text")
+
+
+def storage_object_exist(filename, storage_client=None, bucket_name=None):
+    if storage_client is None:
+        raise Exception("storage_client is None")
+
+    if bucket_name is None or _storage_bucket_exist(storage_client, bucket_name) is False:
+        raise Exception("storage bucket is Not exist")
+
+    bucket = storage_client.get_bucket(bucket_name)
+    return bucket.blob(filename).exists()
+
+
+def storage_object_remove(filename, storage_client=None, bucket_name=None):
+    if storage_client is None:
+        raise Exception("storage_client is None")
+
+    if bucket_name is None or _storage_bucket_exist(storage_client, bucket_name) is False:
+        raise Exception("storage bucket is Not exist")
+
+    bucket = storage_client.get_bucket(bucket_name)
+    blob = bucket.blob(filename)
+    try:
+        blob.delete()
+    except NotFound:
+        pass
+
+    if storage_object_exist(filename, storage_client, bucket_name):
+        return False
+    return True
+
+
+def storage_object_load(filename, storage_client=None, bucket_name=None):
+    if storage_client is None:
+        raise Exception("storage_client is None")
+
+    if bucket_name is None or _storage_bucket_exist(storage_client, bucket_name) is False:
+        raise Exception("storage bucket is Not exist")
+
+    bucket = storage_client.get_bucket(bucket_name)
+    blob = bucket.blob(filename)
+    return blob.download_as_string()
+
+
+def _storage_bucket_exist(storage_client, bucket_name):
+    from google.cloud.storage import Bucket
+
+    exists = Bucket(storage_client, bucket_name).exists()
+
+    return exists
