@@ -51,7 +51,7 @@ def get_pkl_from_hdfs(pkl_path):
     return pkl_object
 
 
-def get_spark(scale=0, queue=None):
+def get_spark(scale=0, queue=None, jars=None):
     import os
     import uuid
     import tempfile
@@ -77,11 +77,13 @@ def get_spark(scale=0, queue=None):
             queue = "airflow_job"
 
     bigquery_jars = (
-        "hdfs:///jars/spark-bigquery-with-dependencies_2.12-0.21.0.jar"
+        "hdfs:///jars/spark-bigquery-with-dependencies_2.12-0.24.2.jar"
         if is_spark_3
         else "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar"
     )
 
+    spark_jars = ",".join([bigquery_jars, jars]) if jars else bigquery_jars
+
     arrow_enabled = "spark.sql.execution.arrow.pyspark.enabled" if is_spark_3 else "spark.sql.execution.arrow.enabled"
 
     arrow_pre_ipc_format = "0" if is_spark_3 else "1"
@@ -92,7 +94,6 @@ def get_spark(scale=0, queue=None):
             SparkSession.builder.config("spark.app.name", app_name)
             .config("spark.driver.memory", "6g")
             .config("spark.executor.memory", "4g")
-            .config("spark.shuffle.service.enabled", "true")
             .config("spark.driver.maxResultSize", "6g")
             .config("spark.rpc.message.maxSize", "1024")
             .config("spark.executor.core", "4")
@@ -104,7 +105,7 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
             .config(
                 "spark.jars",
-                bigquery_jars,
+                spark_jars,
             )
             .enableHiveSupport()
             .getOrCreate()
@@ -127,7 +128,7 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
             .config(
                 "spark.jars",
-                bigquery_jars,
+                spark_jars,
             )
             .enableHiveSupport()
             .getOrCreate()
@@ -147,7 +148,7 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
             .config(
                 "spark.jars",
-                bigquery_jars,
+                spark_jars,
             )
             .enableHiveSupport()
             .getOrCreate()
@@ -168,7 +169,7 @@ def get_spark(scale=0, queue=None):
                 .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
                 .config(
                     "spark.jars",
-                    bigquery_jars,
+                    spark_jars,
                 )
                 .enableHiveSupport()
                 .getOrCreate()
@@ -190,7 +191,7 @@ def get_spark(scale=0, queue=None):
                 .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
                 .config(
                     "spark.jars",
-                    bigquery_jars,
+                    spark_jars,
                 )
                 .enableHiveSupport()
                 .getOrCreate()
